@@ -1,4 +1,15 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 import re
@@ -64,7 +75,8 @@ class Cpu(checks.AgentCheck):
 
     def _add_cpu_freq(self, data):
         try:
-            lscpu_command = subprocess.Popen('lscpu', stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            lscpu_command = subprocess.Popen(
+                'lscpu', stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             lscpu_output = lscpu_command.communicate()[0].decode(
                 encoding='UTF-8')
             cpu_freq_output = re.search("(CPU MHz:.*?(\d+\.\d+)\n)", lscpu_output)
