@@ -1,4 +1,15 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import collections
 import logging
@@ -88,14 +99,18 @@ class KafkaCheck(checks.AgentCheck):
                         kafka_consumer.stop()
                     continue
 
-                # Remember the topic partitions encountered so that we can look up their broker offsets later
+                # Remember the topic partitions encountered so that we can look up their
+                # broker offsets later
                 topic_partitions[topic].update(set(partitions))
                 consumer_offsets[(consumer_group, topic)] = {}
                 for partition in partitions:
                     try:
-                        consumer_offsets[(consumer_group, topic)][partition] = kafka_consumer.offsets[partition]
+                        consumer_offsets[(consumer_group,
+                                          topic)][partition] = kafka_consumer.offsets[partition]
                     except KeyError:
-                        self.log.error('Error fetching consumer offset for {0} partition {1}'.format(topic, partition))
+                        self.log.error(
+                            'Error fetching consumer offset for {0} partition {1}'.format(
+                                topic, partition))
 
                 kafka_consumer.stop()
 
@@ -106,7 +121,8 @@ class KafkaCheck(checks.AgentCheck):
             offset_responses = []
             for p in partitions:
                 try:
-                    response = kafka_conn.send_offset_request([common.OffsetRequest(topic, p, -1, 1)])
+                    response = kafka_conn.send_offset_request(
+                        [common.OffsetRequest(topic, p, -1, 1)])
                     offset_responses.append(response[0])
                 except common.KafkaError as e:
                     self.log.error("Error fetching broker offset: {0}".format(e))
