@@ -1,4 +1,15 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import urllib2
 
@@ -118,11 +129,14 @@ class Lighttpd(AgentCheck):
             if self.assumed_url.get(instance['lighttpd_status_url'],
                                     None) is None and url[-len(url_suffix):] != url_suffix:
                 self.assumed_url[instance['lighttpd_status_url']] = '%s%s' % (url, url_suffix)
-                self.log.warn("Assuming url was not correct. Trying to add %s suffix to the url" % url_suffix)
+                self.log.warn(
+                    "Assuming url was not correct. Trying to add %s suffix to the url" %
+                    url_suffix)
                 self.check(instance)
             else:
                 raise Exception(
-                    "No metrics were fetched for this instance. Make sure that %s is the proper url." %
+                    "No metrics were fetched for this instance. "
+                    "Make sure that %s is the proper url." %
                     instance['lighttpd_status_url'])
 
     def _get_server_version(self, headers):
