@@ -1,5 +1,16 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
 # Copyright 2017 Fujitsu LIMITED
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 
@@ -47,7 +58,8 @@ def get_session(**kwargs):
     - using **Keystone v3** be careful with the scope of authentication.
       For more details about scopes refer to identity_tokens_ and v3_identity_
 
-    .. _v3_api: https://developer.openstack.org/api-ref/identity/v3/index.html?expanded=token-authentication-with-scoped-authorization-detail
+    .. _v3_api: https://developer.openstack.org/api-ref/identity/v3/index.html?expanded=token-authe
+    ntication-with-scoped-authorization-detail
     .. _identity_tokens: https://docs.openstack.org/admin-guide/identity-tokens.html
 
     In overall:
